@@ -401,6 +401,13 @@ def add_branch(tree,low,high,threshold_exponent=1.5,threshold_adjuster=0.75,
             assert not np.any(np.isnan(tree.data[:,28])), "28 Nan found prior to local optimization"
             assert not np.any(np.isnan(tree.data[:,29])), "29 Nan found prior to local optimization"
             assert not np.any(np.isnan(tree.data[:,30])), "30 Nan found prior to local optimization"
+
+            assert not np.any(np.isclose(tree.data[:,20],0)), "20 0 found prior to local optimization"
+            assert not np.any(np.isclose(tree.data[:,21],0)), "21 0 found prior to local optimization"
+            assert not np.any(np.isclose(tree.data[:,22],0)), "22 0 found prior to local optimization"
+            #assert not np.any(np.isclose(tree.data[:,23],0)), "23 Nan found prior to local optimization"
+            #assert not np.any(np.isclose(tree.data[:,24],0)), "24 Nan found prior to local optimization"
+            assert not np.any(np.isclose(tree.data[:,25],0)), "25 0 found prior to local optimization"
             results = fast_local_function(tree.data,points,terminal,
                                           vessel,gamma,nu,Qterm,Pperm,Pterm)
             assert not np.any(np.isnan(results[0])), "Nan found after local optimization"
